@@ -346,6 +346,13 @@ int search_chunk(f_state *s, unsigned char *buf, f_info *i, u_int64_t chunk_size
 			needle->written = FALSE;
 			found_ind = FALSE;
 			memset(needle->comment, 0, COMMENT_LENGTH - 1);
+                        if (chunk_size <= (foundat - buf)) {
+#ifdef DEBUG
+				printf("avoided seg fault in search_chunk()\n");
+#endif
+				foundat = NULL;
+				break;
+			}
 			current_buflen = chunk_size - (foundat - buf);
 
 			//if((foundat-buf)< 1 ) break;	
