@@ -1646,6 +1646,80 @@ unsigned char *extract_mpg(f_state *s, u_int64_t c_offset, unsigned char *founda
 	return foundat;
 }
 
+
+/********************************************************************************
+ *Function: extract_mp4
+ * Not done yet
+ **********************************************************************************/
+unsigned char *extract_mp4(f_state *s, u_int64_t c_offset, unsigned char *foundat, u_int64_t buflen,
+						   s_spec *needle, u_int64_t f_offset)
+{
+	unsigned char	*buf = foundat;
+
+	unsigned char	*extractbuf = NULL;
+	unsigned int	size = 0;
+	u_int64_t		file_size = 0;
+
+   
+	while(1)
+	{
+	 	size=htoi(&foundat[28],FOREMOST_BIG_ENDIAN);
+		if(size ==0)
+		{
+			//printf("size ==0\n");
+			foundat+=28;
+			break;
+		}
+    		//printf("size:=%d\n",size);
+		if(size > 0 && size < buflen)
+		{
+			if(!isprint(foundat[32]) ||  !isprint(foundat[33]))
+			{
+				//printf("print err\n");
+				break;
+				//return foundat+8;
+			}
+			foundat+=size;
+			
+		}
+		else
+		{
+			if (size < needle->max_len)
+			{
+				//printf("Searching More\n");
+				return NULL;
+			}
+			else
+			{
+				//printf("ERR\n");
+				//return foundat+8;
+				break;
+			}
+		}	
+	
+		//printx(foundat,0,32);
+
+	}
+	if (foundat)
+	{
+		file_size = (foundat - buf) + needle->footer_len;
+		if (file_size < 1 * KILOBYTE)
+			return buf + needle->header_len;
+	}
+	
+
+	if (file_size > buflen)
+		file_size = buflen;
+	foundat = buf;
+
+
+	extractbuf = buf;	
+	write_to_disk(s, needle, file_size, extractbuf, c_offset + f_offset);
+	foundat += file_size;
+	return foundat;
+}
+
+
 /********************************************************************************
  *Function: extract_png
  *Description: Given that we have a PNG header parse the given buffer to determine
@@ -2438,6 +2512,10 @@ unsigned char *extract_file(f_state *s, u_int64_t c_offset, unsigned char *found
 		{
 		return extract_mpg(s, c_offset, foundat, buflen, needle, f_offset);
 		}
+	else if (needle->type == MP4)
+		{
+		return extract_mp4(s, c_offset, foundat, buflen, needle, f_offset);
+		}
 	else if (needle->type == ZIP)
 		{
 		return extract_zip(s, c_offset, foundat, buflen, needle, f_offset, "all");
