@@ -475,20 +475,34 @@ unsigned int htoi(unsigned char s[], int endian)
 
 u_int64_t htoll(unsigned char s[], int endian)
 {
-	int				length = sizeof(long long);
+	int				length = sizeof(u_int64_t);
 	unsigned char	*bytes = (unsigned char *)malloc(length * sizeof(char));
-	unsigned int	size = 0;
+	u_int64_t	size = 0;
 	bytes = memcpy(bytes, s, length);
+#ifdef DEBUG
+	printf("htoll len=%d endian=%d\n",length,endian);
+#endif	
 	if (endian == FOREMOST_BIG_ENDIAN && BYTE_ORDER == LITTLE_ENDIAN)
 		{
+#ifdef DEBUG
+		printf("reverse0\n");
+#endif
 		bytes = (unsigned char *)reverse_string((char *)bytes, (char *)s, 0, length);
 		}
 	else if (endian == FOREMOST_LITTLE_ENDIAN && BYTE_ORDER == BIG_ENDIAN)
 		{
+#ifdef DEBUG
+	printf("reverse1\n");
+#endif
 		bytes = (unsigned char *)reverse_string((char *)bytes, (char *)s, 0, length);
 		}
 
-	size = *((unsigned long *)bytes);
+	size = *((u_int64_t *)bytes);
+#ifdef DEBUG
+	printf("htoll size=%llu\n",size);
+	printx(bytes,0,length);
+#endif	
+	
 
 	free(bytes);
 	return size;
